# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracles/v1/oracle_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='oracles/v1/oracle_data.proto',
  package='oracles.v1',
  syntax='proto3',
  serialized_options=b'\n\037io.vegaprotocol.vega.oracles.v1Z*code.vegaprotocol.io/vega/proto/oracles/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1coracles/v1/oracle_data.proto\x12\noracles.v1\"\x9e\x01\n\nOracleData\x12\x19\n\x08pub_keys\x18\x01 \x03(\tR\x07pubKeys\x12(\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x14.oracles.v1.PropertyR\x04\x64\x61ta\x12(\n\x10matched_spec_ids\x18\x03 \x03(\tR\x0ematchedSpecIds\x12!\n\x0c\x62roadcast_at\x18\x04 \x01(\x03R\x0b\x62roadcastAt\"4\n\x08Property\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x14\n\x05value\x18\x02 \x01(\tR\x05valueBM\n\x1fio.vegaprotocol.vega.oracles.v1Z*code.vegaprotocol.io/vega/proto/oracles/v1b\x06proto3'
)




_ORACLEDATA = _descriptor.Descriptor(
  name='OracleData',
  full_name='oracles.v1.OracleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_keys', full_name='oracles.v1.OracleData.pub_keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='oracles.v1.OracleData.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matched_spec_ids', full_name='oracles.v1.OracleData.matched_spec_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchedSpecIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broadcast_at', full_name='oracles.v1.OracleData.broadcast_at', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='broadcastAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=203,
)


_PROPERTY = _descriptor.Descriptor(
  name='Property',
  full_name='oracles.v1.Property',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='oracles.v1.Property.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='oracles.v1.Property.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=257,
)

_ORACLEDATA.fields_by_name['data'].message_type = _PROPERTY
DESCRIPTOR.message_types_by_name['OracleData'] = _ORACLEDATA
DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OracleData = _reflection.GeneratedProtocolMessageType('OracleData', (_message.Message,), {
  'DESCRIPTOR' : _ORACLEDATA,
  '__module__' : 'oracles.v1.oracle_data_pb2'
  # @@protoc_insertion_point(class_scope:oracles.v1.OracleData)
  })
_sym_db.RegisterMessage(OracleData)

Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTY,
  '__module__' : 'oracles.v1.oracle_data_pb2'
  # @@protoc_insertion_point(class_scope:oracles.v1.Property)
  })
_sym_db.RegisterMessage(Property)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tm/replay.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tm/replay.proto',
  package='tm',
  syntax='proto3',
  serialized_options=b'\n\027io.vegaprotocol.vega.tmZ\034code.vegaprotocol.io/vega/tm',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0ftm/replay.proto\x12\x02tm\"\x90\x03\n\x07TmEvent\x12<\n\x0ereq_init_chain\x18\x01 \x01(\x0b\x32\x14.tm.RequestInitChainH\x00R\x0creqInitChain\x12=\n\x0eres_init_chain\x18\x02 \x01(\x0b\x32\x15.tm.ResponseInitChainH\x00R\x0cresInitChain\x12<\n\x0ereq_deliver_tx\x18\x03 \x01(\x0b\x32\x14.tm.RequestDeliverTxH\x00R\x0creqDeliverTx\x12=\n\x0eres_deliver_tx\x18\x04 \x01(\x0b\x32\x15.tm.ResponseDeliverTxH\x00R\x0cresDeliverTx\x12?\n\x0freq_begin_block\x18\x05 \x01(\x0b\x32\x15.tm.RequestBeginBlockH\x00R\rreqBeginBlock\x12@\n\x0fres_begin_block\x18\x06 \x01(\x0b\x32\x16.tm.ResponseBeginBlockH\x00R\rresBeginBlockB\x08\n\x06\x61\x63tion\"\x85\x02\n\x10RequestInitChain\x12\x12\n\x04time\x18\x01 \x01(\x03R\x04time\x12\x19\n\x08\x63hain_id\x18\x02 \x01(\tR\x07\x63hainId\x12>\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\x13.tm.ConsensusParamsR\x0f\x63onsensusParams\x12\x33\n\nvalidators\x18\x04 \x03(\x0b\x32\x13.tm.ValidatorUpdateR\nvalidators\x12&\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0cR\rappStateBytes\x12%\n\x0einitial_height\x18\x06 \x01(\x03R\rinitialHeight\"\xca\x01\n\x11RequestBeginBlock\x12\x12\n\x04hash\x18\x01 \x01(\x0cR\x04hash\x12\"\n\x06header\x18\x02 \x01(\x0b\x32\n.tm.HeaderR\x06header\x12<\n\x10last_commit_info\x18\x03 \x01(\x0b\x32\x12.tm.LastCommitInfoR\x0elastCommitInfo\x12?\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\x0c.tm.EvidenceR\x13\x62yzantineValidators\"\"\n\x10RequestDeliverTx\x12\x0e\n\x02tx\x18\x01 \x01(\x0cR\x02tx\"\xa3\x01\n\x11ResponseInitChain\x12>\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\x13.tm.ConsensusParamsR\x0f\x63onsensusParams\x12\x33\n\nvalidators\x18\x02 \x03(\x0b\x32\x13.tm.ValidatorUpdateR\nvalidators\x12\x19\n\x08\x61pp_hash\x18\x03 \x01(\x0cR\x07\x61ppHash\"7\n\x12ResponseBeginBlock\x12!\n\x06\x65vents\x18\x01 \x03(\x0b\x32\t.tm.EventR\x06\x65vents\"\xdc\x01\n\x11ResponseDeliverTx\x12\x12\n\x04\x63ode\x18\x01 \x01(\rR\x04\x63ode\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x10\n\x03log\x18\x03 \x01(\tR\x03log\x12\x12\n\x04info\x18\x04 \x01(\tR\x04info\x12\x1d\n\ngas_wanted\x18\x05 \x01(\x03R\tgasWanted\x12\x19\n\x08gas_used\x18\x06 \x01(\x03R\x07gasUsed\x12!\n\x06\x65vents\x18\x07 \x03(\x0b\x32\t.tm.EventR\x06\x65vents\x12\x1c\n\tcodespace\x18\x08 \x01(\tR\tcodespace\"O\n\x05\x45vent\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x32\n\nattributes\x18\x02 \x03(\x0b\x32\x12.tm.EventAttributeR\nattributes\"N\n\x0e\x45ventAttribute\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x0cR\x05value\x12\x14\n\x05index\x18\x03 \x01(\x08R\x05index\"O\n\x0fValidatorUpdate\x12&\n\x07pub_key\x18\x01 \x01(\x0b\x32\r.tm.PublicKeyR\x06pubKey\x12\x14\n\x05power\x18\x02 \x01(\x03R\x05power\"\xc8\x01\n\x0f\x43onsensusParams\x12%\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x0f.tm.BlockParamsR\x05\x62lock\x12.\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x12.tm.EvidenceParamsR\x08\x65vidence\x12\x31\n\tvalidator\x18\x03 \x01(\x0b\x32\x13.tm.ValidatorParamsR\tvalidator\x12+\n\x07version\x18\x04 \x01(\x0b\x32\x11.tm.VersionParamsR\x07version\"C\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGas\"\xb7\x01\n\x08\x45vidence\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x10.tm.EvidenceTypeR\x04type\x12+\n\tvalidator\x18\x02 \x01(\x0b\x32\r.tm.ValidatorR\tvalidator\x12\x16\n\x06height\x18\x03 \x01(\x03R\x06height\x12\x12\n\x04time\x18\x04 \x01(\x03R\x04time\x12,\n\x12total_voting_power\x18\x05 \x01(\x03R\x10totalVotingPower\";\n\tValidator\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0cR\x07\x61\x64\x64ress\x12\x14\n\x05power\x18\x03 \x01(\x03R\x05power\"J\n\x0eLastCommitInfo\x12\x14\n\x05round\x18\x01 \x01(\x05R\x05round\x12\"\n\x05votes\x18\x02 \x03(\x0b\x32\x0c.tm.VoteInfoR\x05votes\"c\n\x08VoteInfo\x12+\n\tvalidator\x18\x01 \x01(\x0b\x32\r.tm.ValidatorR\tvalidator\x12*\n\x11signed_last_block\x18\x02 \x01(\x08R\x0fsignedLastBlock\"\x80\x01\n\x0e\x45videnceParams\x12+\n\x12max_age_num_blocks\x18\x01 \x01(\x03R\x0fmaxAgeNumBlocks\x12(\n\x10max_age_duration\x18\x02 \x01(\x03R\x0emaxAgeDuration\x12\x17\n\x07max_num\x18\x03 \x01(\rR\x06maxNum\"5\n\x0fValidatorParams\x12\"\n\rpub_key_types\x18\x01 \x03(\tR\x0bpubKeyTypes\"0\n\rVersionParams\x12\x1f\n\x0b\x61pp_version\x18\x01 \x01(\x04R\nappVersion\"O\n\x06Header\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\x12\x16\n\x06height\x18\x02 \x01(\x03R\x06height\x12\x12\n\x04time\x18\x03 \x01(\x03R\x04time\".\n\tPublicKey\x12\x1a\n\x07\x65\x64\x32\x35\x35\x31\x39\x18\x01 \x01(\x0cH\x00R\x07\x65\x64\x32\x35\x35\x31\x39\x42\x05\n\x03sum*H\n\x0c\x45videnceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x42\x37\n\x17io.vegaprotocol.vega.tmZ\x1c\x63ode.vegaprotocol.io/vega/tmb\x06proto3'
)

_EVIDENCETYPE = _descriptor.EnumDescriptor(
  name='EvidenceType',
  full_name='tm.EvidenceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_VOTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHT_CLIENT_ATTACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2680,
  serialized_end=2752,
)
_sym_db.RegisterEnumDescriptor(_EVIDENCETYPE)

EvidenceType = enum_type_wrapper.EnumTypeWrapper(_EVIDENCETYPE)
UNKNOWN = 0
DUPLICATE_VOTE = 1
LIGHT_CLIENT_ATTACK = 2



_TMEVENT = _descriptor.Descriptor(
  name='TmEvent',
  full_name='tm.TmEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_init_chain', full_name='tm.TmEvent.req_init_chain', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqInitChain', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='res_init_chain', full_name='tm.TmEvent.res_init_chain', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resInitChain', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_deliver_tx', full_name='tm.TmEvent.req_deliver_tx', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqDeliverTx', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='res_deliver_tx', full_name='tm.TmEvent.res_deliver_tx', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resDeliverTx', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='req_begin_block', full_name='tm.TmEvent.req_begin_block', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reqBeginBlock', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='res_begin_block', full_name='tm.TmEvent.res_begin_block', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resBeginBlock', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='action', full_name='tm.TmEvent.action',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=24,
  serialized_end=424,
)


_REQUESTINITCHAIN = _descriptor.Descriptor(
  name='RequestInitChain',
  full_name='tm.RequestInitChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='tm.RequestInitChain.time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tm.RequestInitChain.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='chainId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_params', full_name='tm.RequestInitChain.consensus_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='consensusParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='tm.RequestInitChain.validators', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validators', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_state_bytes', full_name='tm.RequestInitChain.app_state_bytes', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='appStateBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_height', full_name='tm.RequestInitChain.initial_height', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='initialHeight', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=688,
)


_REQUESTBEGINBLOCK = _descriptor.Descriptor(
  name='RequestBeginBlock',
  full_name='tm.RequestBeginBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='tm.RequestBeginBlock.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='tm.RequestBeginBlock.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='header', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_commit_info', full_name='tm.RequestBeginBlock.last_commit_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastCommitInfo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byzantine_validators', full_name='tm.RequestBeginBlock.byzantine_validators', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='byzantineValidators', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=893,
)


_REQUESTDELIVERTX = _descriptor.Descriptor(
  name='RequestDeliverTx',
  full_name='tm.RequestDeliverTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='tm.RequestDeliverTx.tx', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tx', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=929,
)


_RESPONSEINITCHAIN = _descriptor.Descriptor(
  name='ResponseInitChain',
  full_name='tm.ResponseInitChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consensus_params', full_name='tm.ResponseInitChain.consensus_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='consensusParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='tm.ResponseInitChain.validators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validators', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_hash', full_name='tm.ResponseInitChain.app_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='appHash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1095,
)


_RESPONSEBEGINBLOCK = _descriptor.Descriptor(
  name='ResponseBeginBlock',
  full_name='tm.ResponseBeginBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='tm.ResponseBeginBlock.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1152,
)


_RESPONSEDELIVERTX = _descriptor.Descriptor(
  name='ResponseDeliverTx',
  full_name='tm.ResponseDeliverTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='tm.ResponseDeliverTx.code', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='tm.ResponseDeliverTx.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='tm.ResponseDeliverTx.log', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='log', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='tm.ResponseDeliverTx.info', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_wanted', full_name='tm.ResponseDeliverTx.gas_wanted', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gasWanted', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_used', full_name='tm.ResponseDeliverTx.gas_used', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gasUsed', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='events', full_name='tm.ResponseDeliverTx.events', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='events', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codespace', full_name='tm.ResponseDeliverTx.codespace', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='codespace', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1375,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='tm.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='tm.Event.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='tm.Event.attributes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='attributes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1377,
  serialized_end=1456,
)


_EVENTATTRIBUTE = _descriptor.Descriptor(
  name='EventAttribute',
  full_name='tm.EventAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tm.EventAttribute.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tm.EventAttribute.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='tm.EventAttribute.index', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='index', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1458,
  serialized_end=1536,
)


_VALIDATORUPDATE = _descriptor.Descriptor(
  name='ValidatorUpdate',
  full_name='tm.ValidatorUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='tm.ValidatorUpdate.pub_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='tm.ValidatorUpdate.power', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='power', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1617,
)


_CONSENSUSPARAMS = _descriptor.Descriptor(
  name='ConsensusParams',
  full_name='tm.ConsensusParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='tm.ConsensusParams.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='block', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evidence', full_name='tm.ConsensusParams.evidence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='evidence', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='tm.ConsensusParams.validator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='tm.ConsensusParams.version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1620,
  serialized_end=1820,
)


_BLOCKPARAMS = _descriptor.Descriptor(
  name='BlockParams',
  full_name='tm.BlockParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_bytes', full_name='tm.BlockParams.max_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_gas', full_name='tm.BlockParams.max_gas', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxGas', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1889,
)


_EVIDENCE = _descriptor.Descriptor(
  name='Evidence',
  full_name='tm.Evidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='tm.Evidence.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validator', full_name='tm.Evidence.validator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tm.Evidence.height', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='tm.Evidence.time', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_voting_power', full_name='tm.Evidence.total_voting_power', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='totalVotingPower', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=2075,
)


_VALIDATOR = _descriptor.Descriptor(
  name='Validator',
  full_name='tm.Validator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='tm.Validator.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='address', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='power', full_name='tm.Validator.power', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='power', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2077,
  serialized_end=2136,
)


_LASTCOMMITINFO = _descriptor.Descriptor(
  name='LastCommitInfo',
  full_name='tm.LastCommitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='tm.LastCommitInfo.round', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='round', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='votes', full_name='tm.LastCommitInfo.votes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='votes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2138,
  serialized_end=2212,
)


_VOTEINFO = _descriptor.Descriptor(
  name='VoteInfo',
  full_name='tm.VoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator', full_name='tm.VoteInfo.validator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='validator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_last_block', full_name='tm.VoteInfo.signed_last_block', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signedLastBlock', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2214,
  serialized_end=2313,
)


_EVIDENCEPARAMS = _descriptor.Descriptor(
  name='EvidenceParams',
  full_name='tm.EvidenceParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_age_num_blocks', full_name='tm.EvidenceParams.max_age_num_blocks', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxAgeNumBlocks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_age_duration', full_name='tm.EvidenceParams.max_age_duration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxAgeDuration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_num', full_name='tm.EvidenceParams.max_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxNum', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2316,
  serialized_end=2444,
)


_VALIDATORPARAMS = _descriptor.Descriptor(
  name='ValidatorParams',
  full_name='tm.ValidatorParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key_types', full_name='tm.ValidatorParams.pub_key_types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKeyTypes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2446,
  serialized_end=2499,
)


_VERSIONPARAMS = _descriptor.Descriptor(
  name='VersionParams',
  full_name='tm.VersionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_version', full_name='tm.VersionParams.app_version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='appVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2501,
  serialized_end=2549,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='tm.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tm.Header.chain_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='chainId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='tm.Header.height', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='height', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='tm.Header.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2551,
  serialized_end=2630,
)


_PUBLICKEY = _descriptor.Descriptor(
  name='PublicKey',
  full_name='tm.PublicKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ed25519', full_name='tm.PublicKey.ed25519', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ed25519', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tm.PublicKey.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2632,
  serialized_end=2678,
)

_TMEVENT.fields_by_name['req_init_chain'].message_type = _REQUESTINITCHAIN
_TMEVENT.fields_by_name['res_init_chain'].message_type = _RESPONSEINITCHAIN
_TMEVENT.fields_by_name['req_deliver_tx'].message_type = _REQUESTDELIVERTX
_TMEVENT.fields_by_name['res_deliver_tx'].message_type = _RESPONSEDELIVERTX
_TMEVENT.fields_by_name['req_begin_block'].message_type = _REQUESTBEGINBLOCK
_TMEVENT.fields_by_name['res_begin_block'].message_type = _RESPONSEBEGINBLOCK
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['req_init_chain'])
_TMEVENT.fields_by_name['req_init_chain'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['res_init_chain'])
_TMEVENT.fields_by_name['res_init_chain'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['req_deliver_tx'])
_TMEVENT.fields_by_name['req_deliver_tx'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['res_deliver_tx'])
_TMEVENT.fields_by_name['res_deliver_tx'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['req_begin_block'])
_TMEVENT.fields_by_name['req_begin_block'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_TMEVENT.oneofs_by_name['action'].fields.append(
  _TMEVENT.fields_by_name['res_begin_block'])
_TMEVENT.fields_by_name['res_begin_block'].containing_oneof = _TMEVENT.oneofs_by_name['action']
_REQUESTINITCHAIN.fields_by_name['consensus_params'].message_type = _CONSENSUSPARAMS
_REQUESTINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_REQUESTBEGINBLOCK.fields_by_name['header'].message_type = _HEADER
_REQUESTBEGINBLOCK.fields_by_name['last_commit_info'].message_type = _LASTCOMMITINFO
_REQUESTBEGINBLOCK.fields_by_name['byzantine_validators'].message_type = _EVIDENCE
_RESPONSEINITCHAIN.fields_by_name['consensus_params'].message_type = _CONSENSUSPARAMS
_RESPONSEINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_RESPONSEBEGINBLOCK.fields_by_name['events'].message_type = _EVENT
_RESPONSEDELIVERTX.fields_by_name['events'].message_type = _EVENT
_EVENT.fields_by_name['attributes'].message_type = _EVENTATTRIBUTE
_VALIDATORUPDATE.fields_by_name['pub_key'].message_type = _PUBLICKEY
_CONSENSUSPARAMS.fields_by_name['block'].message_type = _BLOCKPARAMS
_CONSENSUSPARAMS.fields_by_name['evidence'].message_type = _EVIDENCEPARAMS
_CONSENSUSPARAMS.fields_by_name['validator'].message_type = _VALIDATORPARAMS
_CONSENSUSPARAMS.fields_by_name['version'].message_type = _VERSIONPARAMS
_EVIDENCE.fields_by_name['type'].enum_type = _EVIDENCETYPE
_EVIDENCE.fields_by_name['validator'].message_type = _VALIDATOR
_LASTCOMMITINFO.fields_by_name['votes'].message_type = _VOTEINFO
_VOTEINFO.fields_by_name['validator'].message_type = _VALIDATOR
_PUBLICKEY.oneofs_by_name['sum'].fields.append(
  _PUBLICKEY.fields_by_name['ed25519'])
_PUBLICKEY.fields_by_name['ed25519'].containing_oneof = _PUBLICKEY.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['TmEvent'] = _TMEVENT
DESCRIPTOR.message_types_by_name['RequestInitChain'] = _REQUESTINITCHAIN
DESCRIPTOR.message_types_by_name['RequestBeginBlock'] = _REQUESTBEGINBLOCK
DESCRIPTOR.message_types_by_name['RequestDeliverTx'] = _REQUESTDELIVERTX
DESCRIPTOR.message_types_by_name['ResponseInitChain'] = _RESPONSEINITCHAIN
DESCRIPTOR.message_types_by_name['ResponseBeginBlock'] = _RESPONSEBEGINBLOCK
DESCRIPTOR.message_types_by_name['ResponseDeliverTx'] = _RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EventAttribute'] = _EVENTATTRIBUTE
DESCRIPTOR.message_types_by_name['ValidatorUpdate'] = _VALIDATORUPDATE
DESCRIPTOR.message_types_by_name['ConsensusParams'] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['BlockParams'] = _BLOCKPARAMS
DESCRIPTOR.message_types_by_name['Evidence'] = _EVIDENCE
DESCRIPTOR.message_types_by_name['Validator'] = _VALIDATOR
DESCRIPTOR.message_types_by_name['LastCommitInfo'] = _LASTCOMMITINFO
DESCRIPTOR.message_types_by_name['VoteInfo'] = _VOTEINFO
DESCRIPTOR.message_types_by_name['EvidenceParams'] = _EVIDENCEPARAMS
DESCRIPTOR.message_types_by_name['ValidatorParams'] = _VALIDATORPARAMS
DESCRIPTOR.message_types_by_name['VersionParams'] = _VERSIONPARAMS
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['PublicKey'] = _PUBLICKEY
DESCRIPTOR.enum_types_by_name['EvidenceType'] = _EVIDENCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TmEvent = _reflection.GeneratedProtocolMessageType('TmEvent', (_message.Message,), {
  'DESCRIPTOR' : _TMEVENT,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.TmEvent)
  })
_sym_db.RegisterMessage(TmEvent)

RequestInitChain = _reflection.GeneratedProtocolMessageType('RequestInitChain', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTINITCHAIN,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.RequestInitChain)
  })
_sym_db.RegisterMessage(RequestInitChain)

RequestBeginBlock = _reflection.GeneratedProtocolMessageType('RequestBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTBEGINBLOCK,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.RequestBeginBlock)
  })
_sym_db.RegisterMessage(RequestBeginBlock)

RequestDeliverTx = _reflection.GeneratedProtocolMessageType('RequestDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDELIVERTX,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.RequestDeliverTx)
  })
_sym_db.RegisterMessage(RequestDeliverTx)

ResponseInitChain = _reflection.GeneratedProtocolMessageType('ResponseInitChain', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINITCHAIN,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ResponseInitChain)
  })
_sym_db.RegisterMessage(ResponseInitChain)

ResponseBeginBlock = _reflection.GeneratedProtocolMessageType('ResponseBeginBlock', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEBEGINBLOCK,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ResponseBeginBlock)
  })
_sym_db.RegisterMessage(ResponseBeginBlock)

ResponseDeliverTx = _reflection.GeneratedProtocolMessageType('ResponseDeliverTx', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDELIVERTX,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ResponseDeliverTx)
  })
_sym_db.RegisterMessage(ResponseDeliverTx)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.Event)
  })
_sym_db.RegisterMessage(Event)

EventAttribute = _reflection.GeneratedProtocolMessageType('EventAttribute', (_message.Message,), {
  'DESCRIPTOR' : _EVENTATTRIBUTE,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.EventAttribute)
  })
_sym_db.RegisterMessage(EventAttribute)

ValidatorUpdate = _reflection.GeneratedProtocolMessageType('ValidatorUpdate', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORUPDATE,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ValidatorUpdate)
  })
_sym_db.RegisterMessage(ValidatorUpdate)

ConsensusParams = _reflection.GeneratedProtocolMessageType('ConsensusParams', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSPARAMS,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ConsensusParams)
  })
_sym_db.RegisterMessage(ConsensusParams)

BlockParams = _reflection.GeneratedProtocolMessageType('BlockParams', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKPARAMS,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.BlockParams)
  })
_sym_db.RegisterMessage(BlockParams)

Evidence = _reflection.GeneratedProtocolMessageType('Evidence', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCE,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.Evidence)
  })
_sym_db.RegisterMessage(Evidence)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.Validator)
  })
_sym_db.RegisterMessage(Validator)

LastCommitInfo = _reflection.GeneratedProtocolMessageType('LastCommitInfo', (_message.Message,), {
  'DESCRIPTOR' : _LASTCOMMITINFO,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.LastCommitInfo)
  })
_sym_db.RegisterMessage(LastCommitInfo)

VoteInfo = _reflection.GeneratedProtocolMessageType('VoteInfo', (_message.Message,), {
  'DESCRIPTOR' : _VOTEINFO,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.VoteInfo)
  })
_sym_db.RegisterMessage(VoteInfo)

EvidenceParams = _reflection.GeneratedProtocolMessageType('EvidenceParams', (_message.Message,), {
  'DESCRIPTOR' : _EVIDENCEPARAMS,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.EvidenceParams)
  })
_sym_db.RegisterMessage(EvidenceParams)

ValidatorParams = _reflection.GeneratedProtocolMessageType('ValidatorParams', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORPARAMS,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.ValidatorParams)
  })
_sym_db.RegisterMessage(ValidatorParams)

VersionParams = _reflection.GeneratedProtocolMessageType('VersionParams', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONPARAMS,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.VersionParams)
  })
_sym_db.RegisterMessage(VersionParams)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.Header)
  })
_sym_db.RegisterMessage(Header)

PublicKey = _reflection.GeneratedProtocolMessageType('PublicKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICKEY,
  '__module__' : 'tm.replay_pb2'
  # @@protoc_insertion_point(class_scope:tm.PublicKey)
  })
_sym_db.RegisterMessage(PublicKey)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/mwitkow/go-proto-validators/validator.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/mwitkow/go-proto-validators/validator.proto',
  package='validator',
  syntax='proto2',
  serialized_options=b'\n&com.github.mwitkow.go_proto_validatorsZ0github.com/mwitkow/go-proto-validators;validator',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6github.com/mwitkow/go-proto-validators/validator.proto\x12\tvalidator\x1a google/protobuf/descriptor.proto\"\xbf\x04\n\x0e\x46ieldValidator\x12\x14\n\x05regex\x18\x01 \x01(\tR\x05regex\x12\x15\n\x06int_gt\x18\x02 \x01(\x03R\x05intGt\x12\x15\n\x06int_lt\x18\x03 \x01(\x03R\x05intLt\x12\x1d\n\nmsg_exists\x18\x04 \x01(\x08R\tmsgExists\x12\x1f\n\x0bhuman_error\x18\x05 \x01(\tR\nhumanError\x12\x19\n\x08\x66loat_gt\x18\x06 \x01(\x01R\x07\x66loatGt\x12\x19\n\x08\x66loat_lt\x18\x07 \x01(\x01R\x07\x66loatLt\x12#\n\rfloat_epsilon\x18\x08 \x01(\x01R\x0c\x66loatEpsilon\x12\x1b\n\tfloat_gte\x18\t \x01(\x01R\x08\x66loatGte\x12\x1b\n\tfloat_lte\x18\n \x01(\x01R\x08\x66loatLte\x12(\n\x10string_not_empty\x18\x0b \x01(\x08R\x0estringNotEmpty\x12,\n\x12repeated_count_min\x18\x0c \x01(\x03R\x10repeatedCountMin\x12,\n\x12repeated_count_max\x18\r \x01(\x03R\x10repeatedCountMax\x12\x1b\n\tlength_gt\x18\x0e \x01(\x03R\x08lengthGt\x12\x1b\n\tlength_lt\x18\x0f \x01(\x03R\x08lengthLt\x12\x1b\n\tlength_eq\x18\x10 \x01(\x03R\x08lengthEq\x12\x1c\n\nis_in_enum\x18\x11 \x01(\x08R\x08isInEnum\x12\x19\n\x08uuid_ver\x18\x12 \x01(\x05R\x07uuidVer\",\n\x0eOneofValidator\x12\x1a\n\x08required\x18\x01 \x01(\x08R\x08required:P\n\x05\x66ield\x12\x1d.google.protobuf.FieldOptions\x18\xfc\xfb\x03 \x01(\x0b\x32\x19.validator.FieldValidatorR\x05\x66ield:P\n\x05oneof\x12\x1d.google.protobuf.OneofOptions\x18\xfd\xfb\x03 \x01(\x0b\x32\x19.validator.OneofValidatorR\x05oneofBZ\n&com.github.mwitkow.go_proto_validatorsZ0github.com/mwitkow/go-proto-validators;validator'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


FIELD_FIELD_NUMBER = 65020
field = _descriptor.FieldDescriptor(
  name='field', full_name='validator.field', index=0,
  number=65020, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='field', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONEOF_FIELD_NUMBER = 65021
oneof = _descriptor.FieldDescriptor(
  name='oneof', full_name='validator.oneof', index=1,
  number=65021, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, json_name='oneof', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_FIELDVALIDATOR = _descriptor.Descriptor(
  name='FieldValidator',
  full_name='validator.FieldValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='regex', full_name='validator.FieldValidator.regex', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='regex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_gt', full_name='validator.FieldValidator.int_gt', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='intGt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_lt', full_name='validator.FieldValidator.int_lt', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='intLt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg_exists', full_name='validator.FieldValidator.msg_exists', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='msgExists', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='human_error', full_name='validator.FieldValidator.human_error', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='humanError', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_gt', full_name='validator.FieldValidator.float_gt', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatGt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_lt', full_name='validator.FieldValidator.float_lt', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatLt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_epsilon', full_name='validator.FieldValidator.float_epsilon', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatEpsilon', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_gte', full_name='validator.FieldValidator.float_gte', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatGte', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float_lte', full_name='validator.FieldValidator.float_lte', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='floatLte', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_not_empty', full_name='validator.FieldValidator.string_not_empty', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringNotEmpty', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_count_min', full_name='validator.FieldValidator.repeated_count_min', index=11,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='repeatedCountMin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repeated_count_max', full_name='validator.FieldValidator.repeated_count_max', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='repeatedCountMax', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_gt', full_name='validator.FieldValidator.length_gt', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lengthGt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_lt', full_name='validator.FieldValidator.length_lt', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lengthLt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length_eq', full_name='validator.FieldValidator.length_eq', index=15,
      number=16, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lengthEq', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_in_enum', full_name='validator.FieldValidator.is_in_enum', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isInEnum', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid_ver', full_name='validator.FieldValidator.uuid_ver', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uuidVer', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=104,
  serialized_end=679,
)


_ONEOFVALIDATOR = _descriptor.Descriptor(
  name='OneofValidator',
  full_name='validator.OneofValidator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='required', full_name='validator.OneofValidator.required', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='required', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=681,
  serialized_end=725,
)

DESCRIPTOR.message_types_by_name['FieldValidator'] = _FIELDVALIDATOR
DESCRIPTOR.message_types_by_name['OneofValidator'] = _ONEOFVALIDATOR
DESCRIPTOR.extensions_by_name['field'] = field
DESCRIPTOR.extensions_by_name['oneof'] = oneof
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FieldValidator = _reflection.GeneratedProtocolMessageType('FieldValidator', (_message.Message,), {
  'DESCRIPTOR' : _FIELDVALIDATOR,
  '__module__' : 'github.com.mwitkow.go_proto_validators.validator_pb2'
  # @@protoc_insertion_point(class_scope:validator.FieldValidator)
  })
_sym_db.RegisterMessage(FieldValidator)

OneofValidator = _reflection.GeneratedProtocolMessageType('OneofValidator', (_message.Message,), {
  'DESCRIPTOR' : _ONEOFVALIDATOR,
  '__module__' : 'github.com.mwitkow.go_proto_validators.validator_pb2'
  # @@protoc_insertion_point(class_scope:validator.OneofValidator)
  })
_sym_db.RegisterMessage(OneofValidator)

field.message_type = _FIELDVALIDATOR
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(field)
oneof.message_type = _ONEOFVALIDATOR
google_dot_protobuf_dot_descriptor__pb2.OneofOptions.RegisterExtension(oneof)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from . import oracle_data_pb2 as oracle_data
from . import oracle_data_pb2_grpc as oracle_data_grpc
from . import oracle_spec_pb2 as oracle_spec
from . import oracle_spec_pb2_grpc as oracle_spec_grpc

__all__ = [
    "oracle_data",
    "oracle_data_grpc",
    "oracle_spec",
    "oracle_spec_grpc",
]
